# Finac - financial accounting for humans

Finac is a library and function set for Jupyter/ipython, which provides a
simple double-entry bookkeeping database.

## Install

```bash
pip3 install finac
```

Sources: https://github.com/alttch/finac

Documentation: https://finac.readthedocs.io/
